﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Imaging;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Drawing.Drawing2D;
using System.IO;

namespace BatchConvertAndResize
{
    public partial class FormMain : Form
    {
        string[] extensions = new string[] { ".jpg", ".jpeg", ".gif", ".tiff", ".png", ".bmp" };

        public FormMain()
        {
            InitializeComponent();

            cmbFormat.SelectedIndex = 0;
        }

        private void btnStart_Click(object sender, EventArgs e)
        {
            int order = 0;
            foreach (FileInfo file in GetFiles(lblSource.Text))
            {
                ProcessFile(file.FullName, Path.Combine(lblDestination.Text, GetFilename(file, ++order, cmbFormat.Text, txbMask.Text)), (int)txbWidth.Value, (int)txbHeight.Value);
                if (chbDelete.Checked)
                    File.Delete(file.FullName);
            }
        }

        protected void ProcessFile(string source, string destination, int width, int height)
        {
            Image originalImage = Image.FromFile(source, true);

            PixelFormat pixelFormat = originalImage.PixelFormat;
            if (pixelFormat.ToString().Contains("Indexed"))
                pixelFormat = PixelFormat.Format24bppRgb;

            using (Bitmap newImage = new Bitmap(width, height, pixelFormat))
            {
                using (Graphics Canvas = Graphics.FromImage(newImage))
                {
                    Canvas.SmoothingMode = SmoothingMode.AntiAlias;
                    Canvas.InterpolationMode = InterpolationMode.HighQualityBicubic;
                    Canvas.PixelOffsetMode = PixelOffsetMode.HighQuality;
                    Canvas.DrawImage(originalImage, new Rectangle(0, 0, width, height));
                    newImage.Save(destination, GetFileFormat(Path.GetExtension(destination)));
                }
            }
        }

        protected ImageFormat GetFileFormat(string extension)
        {
            if (extension == ".jpg")
                return ImageFormat.Jpeg;
            if (extension == ".tiff")
                return ImageFormat.Tiff;
            if (extension == ".png")
                return ImageFormat.Png;
            if (extension == ".gif")
                return ImageFormat.Gif;
            if (extension == ".bmp")
                return ImageFormat.Bmp;
            return ImageFormat.Exif;
        }

        protected IList<FileInfo> GetFiles(string startPath)
        {
            DirectoryInfo dir = new DirectoryInfo(startPath);
            List<FileInfo> files = new List<FileInfo>();

            foreach (string extension in extensions)
                files.AddRange(dir.GetFiles("*" + extension));

            return files;
        }

        protected string GetFilename(FileInfo file, int order, string extension, string template)
        {
            return template
                .Replace("{filename}", file.Name)
                .Replace("{order}", order.ToString())
                .Replace("{extension}", extension);
        }

        private void btnSource_Click(object sender, EventArgs e)
        {
            if (folderBrowserDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                lblSource.Text = folderBrowserDialog.SelectedPath;
            }
        }

        private void btnDestination_Click(object sender, EventArgs e)
        {
            if (folderBrowserDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                lblDestination.Text = folderBrowserDialog.SelectedPath;
            }

        }
    }
}
